Index: webrtc/api/peerconnectioninterface.h |
diff --git a/webrtc/api/peerconnectioninterface.h b/webrtc/api/peerconnectioninterface.h |
index 7a833438621737e624552b9cdac60285a5d6c7c4..f6c8cbaf00bd0d93b2b7c60cd13506928b9a9de5 100644 |
--- a/webrtc/api/peerconnectioninterface.h |
+++ b/webrtc/api/peerconnectioninterface.h |
@@ -563,23 +563,23 @@ class PeerConnectionFactoryInterface : public rtc::RefCountInterface { |
virtual rtc::scoped_refptr<AudioSourceInterface> CreateAudioSource( |
const MediaConstraintsInterface* constraints) = 0; |
// Creates a VideoSourceInterface. The new source take ownership of |
// |capturer|. |
- virtual rtc::scoped_refptr<VideoSourceInterface> CreateVideoSource( |
+ virtual rtc::scoped_refptr<VideoTrackSourceInterface> CreateVideoSource( |
cricket::VideoCapturer* capturer) = 0; |
// A video source creator that allows selection of resolution and frame rate. |
// |constraints| decides video resolution and frame rate but can |
// be NULL. |
// In the NULL case, use the version above. |
- virtual rtc::scoped_refptr<VideoSourceInterface> CreateVideoSource( |
+ virtual rtc::scoped_refptr<VideoTrackSourceInterface> CreateVideoSource( |
cricket::VideoCapturer* capturer, |
const MediaConstraintsInterface* constraints) = 0; |
// Creates a new local VideoTrack. The same |source| can be used in several |
// tracks. |
- virtual rtc::scoped_refptr<VideoTrackInterface> |
- CreateVideoTrack(const std::string& label, |
- VideoSourceInterface* source) = 0; |
+ virtual rtc::scoped_refptr<VideoTrackInterface> CreateVideoTrack( |
+ const std::string& label, |
+ VideoTrackSourceInterface* source) = 0; |
// Creates an new AudioTrack. At the moment |source| can be NULL. |
virtual rtc::scoped_refptr<AudioTrackInterface> |
@@ -563,23 +563,23 @@ class PeerConnectionFactoryInterface : public rtc::RefCountInterface { |
virtual rtc::scoped_refptr<AudioSourceInterface> CreateAudioSource( |
const MediaConstraintsInterface* constraints) = 0; |
- // Creates a VideoSourceInterface. The new source take ownership of |
+ // Creates a VideoTrackSourceInterface. The new source take ownership of |
// |capturer|. |